@@ -27,8 +27,6 @@ use std::sync::Arc;
 
 use anyhow::{anyhow, Context, Result};
 use cookie_store::{CookieStore, RawCookie};
-#[cfg(feature = "network-interface")]
-use network_interface::{NetworkInterface, NetworkInterfaceConfig};
 use redirect::RedirectFollower;
 use reqwest::blocking::Client;
 use reqwest::header::{
@@ -276,6 +274,10 @@ fn run(args: Cli) -> Result<i32> {
         client = client.http1_only();
     }
 
+    if matches!(args.http_version, Some(HttpVersion::Http2PriorKnowledge)) {
+        client = client.http2_prior_knowledge();
+    }
+
     let cookie_jar = Arc::new(reqwest_cookie_store::CookieStoreMutex::default());
     client = client.cookie_provider(cookie_jar.clone());
 
@@ -286,31 +288,39 @@ fn run(args: Cli) -> Result<i32> {
     };
 
     if let Some(name_or_ip) = &args.interface {
-        let ip_addr = if let Ok(ip_addr) = IpAddr::from_str(name_or_ip) {
-            ip_addr
+        if let Ok(ip_addr) = IpAddr::from_str(name_or_ip) {
+            client = client.local_address(ip_addr);
         } else {
-            #[cfg(not(feature = "network-interface"))]
-            return Err(anyhow!(
-                "This binary was built without support for binding to interfaces. Enable the `network-interface` feature."
-            ));
+            #[cfg(any(target_os = "android", target_os = "fuchsia", target_os = "linux"))]
+            {
+                client = client.interface(name_or_ip);
+            }
 
-            #[cfg(feature = "network-interface")]
-            // TODO: Directly bind to interface name once hyper/reqwest adds support for it.
-            // See https://github.com/seanmonstar/reqwest/issues/1336 and https://github.com/hyperium/hyper/pull/3076
-            NetworkInterface::show()?
-                .iter()
-                .find_map(|interface| {
-                    if &interface.name == name_or_ip {
-                        if let Some(addr) = interface.addr.first() {
-                            return Some(addr.ip());
-                        }
-                    }
-                    None
-                })
-                .with_context(|| format!("Couldn't bind to {:?}", name_or_ip))?
+            #[cfg(not(any(target_os = "android", target_os = "fuchsia", target_os = "linux")))]
+            {
+                #[cfg(not(feature = "network-interface"))]
+                return Err(anyhow!(
+                    "This binary was built without support for binding to interfaces. Enable the `network-interface` feature."
+                ));
+
+                #[cfg(feature = "network-interface")]
+                {
+                    use network_interface::{NetworkInterface, NetworkInterfaceConfig};
+                    let ip_addr = NetworkInterface::show()?
+                        .iter()
+                        .find_map(|interface| {
+                            if &interface.name == name_or_ip {
+                                if let Some(addr) = interface.addr.first() {
+                                    return Some(addr.ip());
+                                }
+                            }
+                            None
+                        })
+                        .with_context(|| format!("Couldn't bind to {:?}", name_or_ip))?;
+                    client = client.local_address(ip_addr);
+                }
+            }
         };
-
-        client = client.local_address(ip_addr);
     }
 
     for resolve in args.resolve {
@@ -370,7 +380,9 @@ fn run(args: Cli) -> Result<i32> {
         request_builder = match args.http_version {
             Some(HttpVersion::Http10) => request_builder.version(reqwest::Version::HTTP_10),
             Some(HttpVersion::Http11) => request_builder.version(reqwest::Version::HTTP_11),
-            Some(HttpVersion::Http2) => request_builder.version(reqwest::Version::HTTP_2),
+            Some(HttpVersion::Http2 | HttpVersion::Http2PriorKnowledge) => {
+                request_builder.version(reqwest::Version::HTTP_2)
+            }
             None => request_builder,
         };
 
