@@ -48,7 +48,7 @@ pub enum RequestItem {
 
 impl FromStr for RequestItem {
     type Err = clap::Error;
-    fn from_str(request_item: &str) -> clap::Result<RequestItem> {
+    fn from_str(request_item: &str) -> clap::error::Result<RequestItem> {
         const SPECIAL_CHARS: &str = "=@:;\\";
         const SEPS: &[&str] = &["==@", "=@", ":=@", ":@", "==", ":=", "=", "@", ":"];
 
@@ -88,7 +88,7 @@ impl FromStr for RequestItem {
                     raw_key,
                     serde_json::from_str(&value).map_err(|err| {
                         clap::Error::raw(
-                            clap::ErrorKind::InvalidValue,
+                            clap::error::ErrorKind::InvalidValue,
                             format!(
                                 "Invalid value for '[REQUEST_ITEM]...': {:?} {}",
                                 request_item, err
@@ -129,7 +129,7 @@ impl FromStr for RequestItem {
             // and was interpreted as a URL, making the actual URL a request
             // item
             Err(clap::Error::raw(
-                clap::ErrorKind::InvalidValue,
+                clap::error::ErrorKind::InvalidValue,
                 format!("Invalid value for '[REQUEST_ITEM]...': {:?}", request_item),
             ))
         }
@@ -220,6 +220,7 @@ pub enum Body {
     File {
         file_name: PathBuf,
         file_type: Option<HeaderValue>,
+        #[allow(dead_code)]
         file_name_header: Option<String>,
     },
 }
@@ -477,8 +478,16 @@ impl RequestItems {
     /// for the benefit of `to_curl`, which sometimes has to process the
     /// request items itself.
     pub fn pick_method(&self) -> Method {
+        if self.is_body_empty() {
+            Method::GET
+        } else {
+            Method::POST
+        }
+    }
+
+    pub fn is_body_empty(&self) -> bool {
         if self.body_type == BodyType::Multipart {
-            return Method::POST;
+            return false;
         }
         for item in &self.items {
             match item {
@@ -491,10 +500,10 @@ impl RequestItems {
                 | RequestItem::DataFieldFromFile { .. }
                 | RequestItem::JsonField(..)
                 | RequestItem::JsonFieldFromFile(..)
-                | RequestItem::FormFile { .. } => return Method::POST,
+                | RequestItem::FormFile { .. } => return false,
             }
         }
-        Method::GET
+        true
     }
 }
 
